@@ -2,10 +2,17 @@ let flexSpec = require('./flex-spec')
 let Declaration = require('../declaration')
 
 class JustifyContent extends Declaration {
+  /**
+   * Return property name by final spec
+   */
+  normalize() {
+    return 'justify-content'
+  }
+
   /**
    * Change property name for 2009 and 2012 specs
    */
-  prefixed (prop, prefix) {
+  prefixed(prop, prefix) {
     let spec
     ;[spec, prefix] = flexSpec(prefix)
     if (spec === 2009) {
@@ -17,17 +24,10 @@ class JustifyContent extends Declaration {
     return super.prefixed(prop, prefix)
   }
 
-  /**
-   * Return property name by final spec
-   */
-  normalize () {
-    return 'justify-content'
-  }
-
   /**
    * Change value for 2009 and 2012 specs
    */
-  set (decl, prefix) {
+  set(decl, prefix) {
     let spec = flexSpec(prefix)[0]
     if (spec === 2009 || spec === 2012) {
       let value = JustifyContent.oldValues[decl.value] || decl.value
@@ -47,8 +47,8 @@ JustifyContent.names = ['justify-content', 'flex-pack', 'box-pack']
 JustifyContent.oldValues = {
   'flex-end': 'end',
   'flex-start': 'start',
-  'space-between': 'justify',
-  'space-around': 'distribute'
+  'space-around': 'distribute',
+  'space-between': 'justify'
 }
 
 module.exports = JustifyContent
