@@ -1,6 +1,22 @@
 let Declaration = require('../declaration')
 
 class UserSelect extends Declaration {
+  /**
+   * Avoid prefixing all in IE
+   */
+  insert(decl, prefix, prefixes) {
+    if (decl.value === 'all' && prefix === '-ms-') {
+      return undefined
+    } else if (
+      decl.value === 'contain' &&
+      (prefix === '-moz-' || prefix === '-webkit-')
+    ) {
+      return undefined
+    } else {
+      return super.insert(decl, prefix, prefixes)
+    }
+  }
+
   /**
    * Change prefixed value for IE
    */
@@ -10,17 +26,6 @@ class UserSelect extends Declaration {
     }
     return super.set(decl, prefix)
   }
-
-  /**
-   * Avoid prefixing all in IE
-   */
-  insert(decl, prefix, prefixes) {
-    if (decl.value === 'all' && prefix === '-ms-') {
-      return undefined
-    } else {
-      return super.insert(decl, prefix, prefixes)
-    }
-  }
 }
 
 UserSelect.names = ['user-select']
