@@ -29,13 +29,13 @@ WritingMode.names = ['writing-mode']
 WritingMode.msValues = {
   ltr: {
     'horizontal-tb': 'lr-tb',
-    'vertical-rl': 'tb-rl',
-    'vertical-lr': 'tb-lr'
+    'vertical-lr': 'tb-lr',
+    'vertical-rl': 'tb-rl'
   },
   rtl: {
     'horizontal-tb': 'rl-tb',
-    'vertical-rl': 'bt-rl',
-    'vertical-lr': 'bt-lr'
+    'vertical-lr': 'bt-lr',
+    'vertical-rl': 'bt-rl'
   }
 }
 
