@@ -1,6 +1,6 @@
 let { equal, match } = require('uvu/assert')
 let browserslist = require('browserslist')
-let { agents } = require('caniuse-lite')
+let { agents } = require('caniuse-lite/dist/unpacker/agents')
 let { test } = require('uvu')
 
 let Browsers = require('../lib/browsers')
@@ -10,18 +10,21 @@ let info = require('../lib/info')
 let data = {
   browsers: agents,
   prefixes: {
+    '@keyframes': {
+      browsers: ['firefox 21']
+    },
     'a': {
       browsers: ['firefox 21', 'firefox 20', 'chrome 30'],
       transition: true
     },
-    'c': {
-      browsers: ['firefox 21'],
-      props: ['c']
-    },
     'b': {
       browsers: ['ie 6', 'firefox 20'],
       props: ['a', '*']
     },
+    'c': {
+      browsers: ['firefox 21'],
+      props: ['c']
+    },
     'd': {
       browsers: ['firefox 21'],
       selector: true
@@ -33,9 +36,6 @@ let data = {
     'grid-row': {
       browsers: ['ie 6']
     },
-    '@keyframes': {
-      browsers: ['firefox 21']
-    },
     'transition': {
       browsers: ['firefox 21']
     }
